Module ui

Module ui 

Structs

Application
Holds the current state of the application such as stats data and currently selected host to render in the UI.
Theme
The collection of colors used in various places in the mtop UI.

Constants

ANSI
MATERIAL
TAILWIND

Functions

initialize_terminal
Disable text output and enable drawing of a UI on standard out.
install_panic_handler
Replace the existing panic handler with one that re-enables text output on standard out before running the default panic handler.
reset_terminal
Re-enable text output on standard out
run
Draw the state of app on terminal until the user exits. Drawing happens every second unless there is user input, in which case it happens immediately.