pub struct Checker { /* private fields */ }Expand description
Repeatedly make connections to a Memcached server to verify connectivity.
Implementations
Sourceimpl Checker
impl Checker
Sourcepub fn new(
client: MemcachedClient,
resolver: Discovery,
delay: Duration,
timeout: Duration,
stop: Arc<AtomicBool>,
) -> Self
pub fn new( client: MemcachedClient, resolver: Discovery, delay: Duration, timeout: Duration, stop: Arc<AtomicBool>, ) -> Self
Create a new Checker that uses connections created from the provided client. delay
is the amount of time to wait between each test. timeout is how long each individual
part of the test may take (DNS resolution, connecting, setting a value, and fetching
a value).
Sourcepub async fn run(&self, host: &str, time: Duration) -> Bundle
pub async fn run(&self, host: &str, time: Duration) -> Bundle
Perform connection tests for a particular host in a loop and return information about the time taken for each step of the test (DNS resolution, connecting, setting a value, and fetching a value) and counts of failures or timeouts during each step.
Note that each test run performs a DNS lookup and creates a brand-new connection.